==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/ResourceRequirementsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ResourceRequirementsFluentImpl<A extends io.fabric8.kubernetes.api.model.ResourceRequirementsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ResourceRequirementsFluent<A>{
  public ResourceRequirementsFluentImpl() {
  }
  public ResourceRequirementsFluentImpl(io.fabric8.kubernetes.api.model.ResourceRequirements instance) {
    this.withLimits(instance.getLimits()); 
    this.withRequests(instance.getRequests()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> limits;
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> requests;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToLimits(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.limits == null && key != null && value != null) { this.limits = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(key != null && value != null) {this.limits.put(key, value);} return (A)this;
  }
  public A addToLimits(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.limits == null && map != null) { this.limits = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(map != null) { this.limits.putAll(map);} return (A)this;
  }
  public A removeFromLimits(java.lang.String key) {
    if(this.limits == null) { return (A) this; }
    if(key != null && this.limits != null) {this.limits.remove(key);} return (A)this;
  }
  public A removeFromLimits(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.limits == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.limits != null){this.limits.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getLimits() {
    return this.limits;
  }
  public <K,V>A withLimits(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> limits) {
    if (limits == null) { this.limits =  null;} else {this.limits = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(limits);} return (A) this;
  }
  public java.lang.Boolean hasLimits() {
    return this.limits != null;
  }
  public A addToRequests(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.requests == null && key != null && value != null) { this.requests = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(key != null && value != null) {this.requests.put(key, value);} return (A)this;
  }
  public A addToRequests(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.requests == null && map != null) { this.requests = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(map != null) { this.requests.putAll(map);} return (A)this;
  }
  public A removeFromRequests(java.lang.String key) {
    if(this.requests == null) { return (A) this; }
    if(key != null && this.requests != null) {this.requests.remove(key);} return (A)this;
  }
  public A removeFromRequests(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.requests == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.requests != null){this.requests.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getRequests() {
    return this.requests;
  }
  public <K,V>A withRequests(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> requests) {
    if (requests == null) { this.requests =  null;} else {this.requests = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(requests);} return (A) this;
  }
  public java.lang.Boolean hasRequests() {
    return this.requests != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceRequirementsFluentImpl that = (ResourceRequirementsFluentImpl) o;
    if (limits != null ? !limits.equals(that.limits) :that.limits != null) return false;
    if (requests != null ? !requests.equals(that.requests) :that.requests != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(limits,  requests,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/ResourceRequirementsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ResourceRequirementsFluentImpl<A extends io.fabric8.kubernetes.api.model.ResourceRequirementsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ResourceRequirementsFluent<A>{
  public ResourceRequirementsFluentImpl() {
  }
  public ResourceRequirementsFluentImpl(io.fabric8.kubernetes.api.model.ResourceRequirements instance) {
    this.withLimits(instance.getLimits()); 
    this.withRequests(instance.getRequests()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> limits;
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> requests;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToLimits(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.limits == null && key != null && value != null) { this.limits = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.limits.put(key, value);} return (A)this;
  }
  public A addToLimits(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.limits == null && map != null) { this.limits = new java.util.LinkedHashMap(); }
    if(map != null) { this.limits.putAll(map);} return (A)this;
  }
  public A removeFromLimits(java.lang.String key) {
    if(this.limits == null) { return (A) this; }
    if(key != null && this.limits != null) {this.limits.remove(key);} return (A)this;
  }
  public A removeFromLimits(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.limits == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.limits != null){this.limits.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getLimits() {
    return this.limits;
  }
  public <K,V>A withLimits(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> limits) {
    if (limits == null) { this.limits =  null;} else {this.limits = new java.util.LinkedHashMap(limits);} return (A) this;
  }
  public java.lang.Boolean hasLimits() {
    return this.limits != null;
  }
  public A addToRequests(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.requests == null && key != null && value != null) { this.requests = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.requests.put(key, value);} return (A)this;
  }
  public A addToRequests(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.requests == null && map != null) { this.requests = new java.util.LinkedHashMap(); }
    if(map != null) { this.requests.putAll(map);} return (A)this;
  }
  public A removeFromRequests(java.lang.String key) {
    if(this.requests == null) { return (A) this; }
    if(key != null && this.requests != null) {this.requests.remove(key);} return (A)this;
  }
  public A removeFromRequests(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.requests == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.requests != null){this.requests.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getRequests() {
    return this.requests;
  }
  public <K,V>A withRequests(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> requests) {
    if (requests == null) { this.requests =  null;} else {this.requests = new java.util.LinkedHashMap(requests);} return (A) this;
  }
  public java.lang.Boolean hasRequests() {
    return this.requests != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceRequirementsFluentImpl that = (ResourceRequirementsFluentImpl) o;
    if (limits != null ? !limits.equals(that.limits) :that.limits != null) return false;
    if (requests != null ? !requests.equals(that.requests) :that.requests != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(limits,  requests,  additionalProperties,  super.hashCode());
  }
  
}
